# -*- coding: utf-8 -*-
#
# Copyright © {{cookiecutter.company}}
# Author: {{cookiecutter.author}}


# ---- Constants
# ------------------------------------------------------
class {{cookiecutter.plugin_class_name}}Actions:
    # Declare plugin actions here
    Test = "test_action"

